@@ -18,10 +18,8 @@ def iam_role():
                         "Action": ["sts:AssumeRole"],
                         "Condition": {
                             "StringLike": {
-                                "iam:AssociatedResourceARN": [
-                                    "arn:aws:ec2:us-east-1:999999999999:instance/*",
-                                ]
-                            },
+                                "iam:AssociatedResourceARN": ["arn:aws:ec2:us-east-1:999999999999:instance/*"]
+                            }
                         },
                     },
                 },
@@ -69,13 +67,17 @@ def test_all_conditions(iam_role):
     }
 
     assert iam_role.assume_role_statement_conditions[0].StringLike == {
-        "iam:AssociatedResourceARN": [
-            "arn:aws:ec2:us-east-1:999999999999:instance/*",
-        ]
+        "iam:AssociatedResourceARN": ["arn:aws:ec2:us-east-1:999999999999:instance/*"]
     }
 
 
-def test_iamrole_policy_documents(iam_role):
+def test_iam_role_policy_documents(iam_role):
     assert iam_role.policy_documents == [
         OptionallyNamedPolicyDocument(name="root", policy_document=iam_role.Properties.Policies[0].PolicyDocument)
     ]
+
+
+def test_iam_role_assume_role_as_optionally_named_policy_document_list(iam_role):
+    assert iam_role.assume_role_as_optionally_named_policy_document_list == [
+        OptionallyNamedPolicyDocument(name=None, policy_document=iam_role.Properties.AssumeRolePolicyDocument)
+    ]
